@@ -23,18 +23,22 @@ class EvalBase():
     def __init__(self, ground_truth_vector_file):
         # Load Ground Truth : Ground Truth should be in geojson or shape file
         try:
-            self.ground_truth_GDF = gpd.read_file(ground_truth_vector_file)
-        except (CPLE_OpenFailedError, DriverError):  # handles empty geojson
-            self.ground_truth_GDF = gpd.GeoDataFrame({'sindex': [],
-                                                      'condition': [],
-                                                      'geometry': []})
+            if ground_truth_vector_file.lower().endswith('json'):
+                self.load_truth(ground_truth_vector_file)
+            elif ground_truth_vector_file.lower().endswith('csv'):
+                self.load_truth(ground_truth_vector_file, truthCSV=True)
+            self.ground_truth_fname = ground_truth_vector_file
         except AttributeError:  # handles passing gdf instead of path to file
             self.ground_truth_GDF = ground_truth_vector_file
+            self.ground_truth_fname = 'GeoDataFrame variable'
         self.ground_truth_sindex = self.ground_truth_GDF.sindex  # get sindex
         # create deep copy of ground truth file for calculations
         self.ground_truth_GDF_Edit = self.ground_truth_GDF.copy(deep=True)
         self.proposal_GDF = gpd.GeoDataFrame([])  # initialize proposal GDF
 
+    def __repr__(self):
+        return 'EvalBase {}'.format(os.path.split(self.ground_truth_fname)[-1])
+
     def eval_iou_spacenet_csv(self, miniou=0.5, iou_field_prefix="iou_score",
                               imageIDField="ImageId", debug=False, minArea=0):
         """Evaluate IoU between the ground truth and proposals in CSVs.
@@ -358,7 +362,6 @@ class EvalBase():
                 by='__total_conf', ascending=False)
         else:
             self.proposal_GDF = gpd.GeoDataFrame(geometry=[])
-        return 0
 
     def load_truth(self, ground_truth_vector_file, truthCSV=False,
                    truth_geo_value='PolygonWKT_Pix'):
@@ -378,7 +381,7 @@ class EvalBase():
 
         Returns
         -------
-        ``0`` if it completes successfully.
+        Nothing.
 
         Notes
         -----
@@ -394,7 +397,7 @@ class EvalBase():
         else:
             try:
                 self.ground_truth_GDF = gpd.read_file(ground_truth_vector_file)
-            except CPLE_OpenFailedError or DriverError:  # empty geojson
+            except (CPLE_OpenFailedError, DriverError):  # empty geojson
                 self.ground_truth_GDF = gpd.GeoDataFrame({'sindex': [],
                                                           'condition': [],
                                                           'geometry': []})
@@ -403,8 +406,6 @@ class EvalBase():
         # create deep copy of ground truth file for calculations
         self.ground_truth_GDF_Edit = self.ground_truth_GDF.copy(deep=True)
 
-        return 0
-
     def eval(self, type='iou'):
         pass
 
